%global python3_pkgversion 3.12
%global srcname Jinja2

Name:           python%{python3_pkgversion}-jinja2-epel
Version:        3.1.3
Release:        1%{?dist}
Summary:        General purpose template engine
License:        BSD-3-Clause
URL:            https://palletsprojects.com/p/jinja/
Source0:        %{pypi_source %srcname}

# Enable building without docs to avoid a circular dependency between this
# and python-sphinx:
%if 0%{?rhel} || 0%{?flatpak}
%bcond_with docs
%else
%bcond_without docs
%endif

BuildArch:      noarch

%global _description %{expand:
Jinja2 is a template engine written in pure Python. It provides a
Django inspired non-XML syntax but supports inline expressions and an
optional sandboxed environment.

If you have any exposure to other text-based template languages, such
as Smarty or Django, you should feel right at home with Jinja2. It's
both designer and developer friendly by sticking to Python's
principles and adding functionality useful for templating
environments.}

%description %_description

%package -n python%{python3_pkgversion}-jinja2
Summary:        %{summary}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-wheel
BuildRequires:  python%{python3_pkgversion}-markupsafe
%if %{with docs}
BuildRequires:  %{_bindir}/sphinx-build-3
BuildRequires:  make
BuildRequires:  python%{python3_pkgversion}-Pallets-Sphinx-Themes >= 2
BuildRequires:  python%{python3_pkgversion}-sphinxcontrib-log-cabinet
BuildRequires:  python%{python3_pkgversion}-sphinx-issues
%endif

%description -n python%{python3_pkgversion}-jinja2 %_description

%pyproject_extras_subpkg -n python%{python3_pkgversion}-jinja2 i18n


%prep
%autosetup -p1 -n %{srcname}-%{version}

# Fix for https://github.com/pallets/jinja/issues/1758
sed -i "s/def teardown/def teardown_method/" tests/test_loader.py

%build
%pyproject_wheel
%if %{with docs}
make -C docs html PYTHONPATH=$(pwd)/src SPHINXBUILD=sphinx-build-3
# remove hidden file
rm -rvf docs/_build/html/.buildinfo
%endif


%install
%pyproject_install
%pyproject_save_files jinja2


%check
%pytest tests


%files -n python%{python3_pkgversion}-jinja2 -f %{pyproject_files}
%doc CHANGES.rst
%doc examples
%license LICENSE.rst
%if %{with docs}
%doc docs/_build/html
%endif


%changelog
* Fri May 24 2024 Orion Poplawski <orion@nwra.com> - 3.1.3-1
- Build for EPEL with Python 3.12
